@@ -112,7 +112,7 @@ typedef struct
 static void     update_display_text (NautilusBatchRenameDialog *dialog);
 static void     cancel_conflict_check (NautilusBatchRenameDialog *self);
 
-G_DEFINE_TYPE (NautilusBatchRenameDialog, nautilus_batch_rename_dialog, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE (NautilusBatchRenameDialog, nautilus_batch_rename_dialog, ADW_TYPE_WINDOW);
 
 static void
 change_numbering_order (GSimpleAction *action,
@@ -248,20 +248,23 @@ add_numbering_tag (GSimpleAction *action,
 
 const GActionEntry dialog_entries[] =
 {
-    { "numbering-order-changed", NULL, "s", "'name-ascending'", change_numbering_order },
-    { "add-numbering-no-zero-pad-tag", add_numbering_tag },
-    { "add-numbering-one-zero-pad-tag", add_numbering_tag },
-    { "add-numbering-two-zero-pad-tag", add_numbering_tag },
-    { "add-original-file-name-tag", add_metadata_tag },
-    { "add-creation-date-tag", add_metadata_tag },
-    { "add-equipment-tag", add_metadata_tag },
-    { "add-season-number-tag", add_metadata_tag },
-    { "add-episode-number-tag", add_metadata_tag },
-    { "add-video-album-tag", add_metadata_tag },
-    { "add-track-number-tag", add_metadata_tag },
-    { "add-artist-name-tag", add_metadata_tag },
-    { "add-title-tag", add_metadata_tag },
-    { "add-album-name-tag", add_metadata_tag },
+    {
+        .name = "numbering-order-changed", .parameter_type = "s", .state = "'name-ascending'",
+        .change_state = change_numbering_order
+    },
+    { .name = "add-numbering-no-zero-pad-tag", .activate = add_numbering_tag },
+    { .name = "add-numbering-one-zero-pad-tag", .activate = add_numbering_tag },
+    { .name = "add-numbering-two-zero-pad-tag", .activate = add_numbering_tag },
+    { .name = "add-original-file-name-tag", .activate = add_metadata_tag },
+    { .name = "add-creation-date-tag", .activate = add_metadata_tag },
+    { .name = "add-equipment-tag", .activate = add_metadata_tag },
+    { .name = "add-season-number-tag", .activate = add_metadata_tag },
+    { .name = "add-episode-number-tag", .activate = add_metadata_tag },
+    { .name = "add-video-album-tag", .activate = add_metadata_tag },
+    { .name = "add-track-number-tag", .activate = add_metadata_tag },
+    { .name = "add-artist-name-tag", .activate = add_metadata_tag },
+    { .name = "add-title-tag", .activate = add_metadata_tag },
+    { .name = "add-album-name-tag", .activate = add_metadata_tag },
 };
 
 static gint
@@ -603,23 +606,15 @@ prepare_batch_rename (NautilusBatchRenameDialog *dialog)
 }
 
 static void
-batch_rename_dialog_on_response (NautilusBatchRenameDialog *dialog,
-                                 gint                       response_id,
-                                 gpointer                   user_data)
+batch_rename_dialog_on_cancel (NautilusBatchRenameDialog *dialog,
+                               gpointer                   user_data)
 {
-    if (response_id == GTK_RESPONSE_OK)
+    if (dialog->directories_pending_conflict_check != NULL)
     {
-        prepare_batch_rename (dialog);
+        cancel_conflict_check (dialog);
     }
-    else
-    {
-        if (dialog->directories_pending_conflict_check != NULL)
-        {
-            cancel_conflict_check (dialog);
-        }
 
-        gtk_window_destroy (GTK_WINDOW (dialog));
-    }
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 static void
@@ -628,9 +623,6 @@ fill_display_listbox (NautilusBatchRenameDialog *dialog)
     GtkWidget *row_child;
     GList *l1;
     GList *l2;
-    NautilusFile *file;
-    GString *new_name;
-    gchar *name;
     GtkTextDirection text_direction;
 
     gtk_size_group_add_widget (dialog->size_group, dialog->result_listbox);
@@ -640,10 +632,9 @@ fill_display_listbox (NautilusBatchRenameDialog *dialog)
 
     for (l1 = dialog->new_names, l2 = dialog->selection; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
     {
-        file = NAUTILUS_FILE (l2->data);
-        new_name = l1->data;
+        const char *name = nautilus_file_get_name (NAUTILUS_FILE (l2->data));
+        GString *new_name = l1->data;
 
-        name = nautilus_file_get_name (file);
         row_child = create_original_name_label (dialog, name);
         gtk_list_box_insert (GTK_LIST_BOX (dialog->original_name_listbox), row_child, -1);
 
@@ -652,8 +643,6 @@ fill_display_listbox (NautilusBatchRenameDialog *dialog)
 
         row_child = create_result_label (dialog, new_name->str);
         gtk_list_box_insert (GTK_LIST_BOX (dialog->result_listbox), row_child, -1);
-
-        g_free (name);
     }
 
     dialog->listbox_labels_old = g_list_reverse (dialog->listbox_labels_old);
@@ -672,7 +661,6 @@ select_nth_conflict (NautilusBatchRenameDialog *dialog)
     gint nth_conflict;
     gint name_occurences;
     GtkAdjustment *adjustment;
-    GtkAllocation allocation;
     ConflictData *conflict_data;
     GtkListBoxRow *list_box_row;
 
@@ -703,8 +691,7 @@ select_nth_conflict (NautilusBatchRenameDialog *dialog)
 
     /* scroll to the selected row */
     adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (dialog->scrolled_window));
-    gtk_widget_get_allocation (GTK_WIDGET (l->data), &allocation);
-    gtk_adjustment_set_value (adjustment, (allocation.height + 1) * nth_conflict_index);
+    gtk_adjustment_set_value (adjustment, (gtk_widget_get_height (GTK_WIDGET (l->data)) + 1) * nth_conflict_index);
 
     name_occurences = 0;
     for (l = dialog->new_names; l != NULL; l = l->next)
@@ -823,15 +810,12 @@ update_listbox (NautilusBatchRenameDialog *dialog)
 {
     GList *l1;
     GList *l2;
-    NautilusFile *file;
-    gchar *old_name;
-    GtkLabel *label;
     GString *new_name;
     gboolean empty_name = FALSE;
 
     for (l1 = dialog->new_names, l2 = dialog->listbox_labels_new; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
     {
-        label = GTK_LABEL (l2->data);
+        GtkLabel *label = GTK_LABEL (l2->data);
         new_name = l1->data;
 
         gtk_label_set_label (label, new_name->str);
@@ -845,10 +829,9 @@ update_listbox (NautilusBatchRenameDialog *dialog)
 
     for (l1 = dialog->selection, l2 = dialog->listbox_labels_old; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
     {
-        label = GTK_LABEL (l2->data);
-        file = NAUTILUS_FILE (l1->data);
+        GtkLabel *label = GTK_LABEL (l2->data);
+        const char *old_name = nautilus_file_get_name (NAUTILUS_FILE (l1->data));
 
-        old_name = nautilus_file_get_name (file);
         gtk_widget_set_tooltip_text (GTK_WIDGET (label), old_name);
 
         if (dialog->mode == NAUTILUS_BATCH_RENAME_DIALOG_FORMAT)
@@ -863,8 +846,6 @@ update_listbox (NautilusBatchRenameDialog *dialog)
 
             g_string_free (new_name, TRUE);
         }
-
-        g_free (old_name);
     }
 
     update_rows_height (dialog);
@@ -932,9 +913,6 @@ check_conflict_for_files (NautilusBatchRenameDialog *dialog,
 {
     gchar *current_directory;
     gchar *parent_uri;
-    gchar *name;
-    NautilusFile *file;
-    GString *new_name;
     GString *file_name;
     GList *l1, *l2;
     GHashTable *directory_files_table;
@@ -967,8 +945,8 @@ check_conflict_for_files (NautilusBatchRenameDialog *dialog,
          l1 != NULL && l2 != NULL;
          l1 = l1->next, l2 = l2->next)
     {
-        new_name = l1->data;
-        file = NAUTILUS_FILE (l2->data);
+        GString *new_name = l1->data;
+        NautilusFile *file = NAUTILUS_FILE (l2->data);
         parent_uri = nautilus_file_get_parent_uri (file);
 
         tag_present = g_hash_table_lookup (new_names_table, new_name->str) != NULL;
@@ -995,24 +973,21 @@ check_conflict_for_files (NautilusBatchRenameDialog *dialog,
 
     for (l1 = files; l1 != NULL; l1 = l1->next)
     {
-        file = NAUTILUS_FILE (l1->data);
+        NautilusFile *file = NAUTILUS_FILE (l1->data);
         g_hash_table_insert (directory_files_table,
-                             nautilus_file_get_name (file),
+                             g_strdup (nautilus_file_get_name (file)),
                              GINT_TO_POINTER (TRUE));
     }
 
     for (l1 = dialog->selection, l2 = dialog->new_names; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
     {
-        file = NAUTILUS_FILE (l1->data);
+        NautilusFile *file = NAUTILUS_FILE (l1->data);
+        GString *new_name = l2->data;
 
-        name = nautilus_file_get_name (file);
-        file_name = g_string_new (name);
-        g_free (name);
+        file_name = g_string_new (nautilus_file_get_name (file));
 
         parent_uri = nautilus_file_get_parent_uri (file);
 
-        new_name = l2->data;
-
         have_conflict = FALSE;
 
         /* check for duplicate only if the parent of the current file is
@@ -1735,6 +1710,16 @@ file_names_widget_entry_on_changed (NautilusBatchRenameDialog *self)
     update_display_text (self);
 }
 
+static void
+nautilus_batch_rename_dialog_dispose (GObject *object)
+{
+    NautilusBatchRenameDialog *dialog = NAUTILUS_BATCH_RENAME_DIALOG (object);
+
+    gtk_widget_dispose_template (GTK_WIDGET (dialog), NAUTILUS_TYPE_BATCH_RENAME_DIALOG);
+
+    G_OBJECT_CLASS (nautilus_batch_rename_dialog_parent_class)->dispose (object);
+}
+
 static void
 nautilus_batch_rename_dialog_finalize (GObject *object)
 {
@@ -1801,12 +1786,12 @@ nautilus_batch_rename_dialog_class_init (NautilusBatchRenameDialogClass *klass)
     widget_class = GTK_WIDGET_CLASS (klass);
     oclass = G_OBJECT_CLASS (klass);
 
+    oclass->dispose = nautilus_batch_rename_dialog_dispose;
     oclass->finalize = nautilus_batch_rename_dialog_finalize;
 
     gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/nautilus/ui/nautilus-batch-rename-dialog.ui");
 
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, grid);
-    gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, cancel_button);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, original_name_listbox);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, arrow_listbox);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, result_listbox);
@@ -1832,7 +1817,8 @@ nautilus_batch_rename_dialog_class_init (NautilusBatchRenameDialogClass *klass)
     gtk_widget_class_bind_template_callback (widget_class, batch_rename_dialog_mode_changed);
     gtk_widget_class_bind_template_callback (widget_class, select_next_conflict_up);
     gtk_widget_class_bind_template_callback (widget_class, select_next_conflict_down);
-    gtk_widget_class_bind_template_callback (widget_class, batch_rename_dialog_on_response);
+    gtk_widget_class_bind_template_callback (widget_class, batch_rename_dialog_on_cancel);
+    gtk_widget_class_bind_template_callback (widget_class, prepare_batch_rename);
 }
 
 GtkWidget *
@@ -1846,7 +1832,7 @@ nautilus_batch_rename_dialog_new (GList             *selection,
     gboolean all_targets_are_folders;
     gboolean all_targets_are_regular_files;
 
-    dialog = g_object_new (NAUTILUS_TYPE_BATCH_RENAME_DIALOG, "use-header-bar", TRUE, NULL);
+    dialog = g_object_new (NAUTILUS_TYPE_BATCH_RENAME_DIALOG, NULL);
 
     dialog->selection = nautilus_file_list_copy (selection);
     dialog->directory = nautilus_directory_ref (directory);
