@@ -55,11 +55,6 @@ gboolean nautilus_is_file_roller_installed           (void);
 GIcon *  nautilus_special_directory_get_icon         (GUserDirectory directory);
 GIcon *  nautilus_special_directory_get_symbolic_icon (GUserDirectory directory);
 
-gboolean nautilus_uri_parse                          (const char  *uri,
-						      char       **host,
-						      guint16     *port,
-						      char       **userinfo);
-
 /* Return an allocated file location that is guranteed to be unique, but
  * tries to make the location name readable to users.
  * This isn't race-free, so don't use for security-related things
@@ -88,8 +83,6 @@ char * get_message_for_two_content_types (const char * const *content_types);
 gboolean should_handle_content_type (const char *content_type);
 gboolean should_handle_content_types (const char * const *content_type);
 
-gboolean nautilus_file_selection_equal (GList *selection_a, GList *selection_b);
-
 /**
  * nautilus_get_common_filename_prefix:
  * @file_list: set of files (NautilusFile *)
@@ -103,14 +96,14 @@ char * nautilus_get_common_filename_prefix (GList *file_list,
 
 /**
  * nautilus_get_common_filename_prefix_from_filenames:
- * @filename_list: set of file names (char *)
+ * @filenames: an array of filenames
  * @min_required_len: the minimum number of characters required in the prefix
  *
  * Returns: the common filename prefix for a set of filenames, or NULL if
  * there isn't a common prefix of length min_required_len
  */
-char * nautilus_get_common_filename_prefix_from_filenames (GList *filename_list,
-                                                           int    min_required_len);
+char * nautilus_get_common_filename_prefix_from_filenames (const char * const *filenames,
+                                                           int                 min_required_len);
 
 /**
  * nautilus_get_max_child_name_for_location:
